@@ -1,6 +1,6 @@
 package IRC::Message::Object;
 {
-  $IRC::Message::Object::VERSION = '0.084002';
+  $IRC::Message::Object::VERSION = '0.085000';
 }
 
 use strictures 1;
@@ -9,14 +9,15 @@ use Moo;
 
 use POE::Filter::IRCv3;
 
-use Exporter 'import';
+use parent 'Exporter::Tiny';
 our @EXPORT_OK = 'ircmsg';
 
+use namespace::clean;
+
 sub ircmsg {
   __PACKAGE__->new(@_)
 }
 
-
 has colonify => (
   is        => 'ro',
   default   => sub { 1 },
@@ -230,9 +231,13 @@ accessors with automatic parsing magic.
 
 =head3 ircmsg
 
-Create a new B<IRC::Message::Object>
+Create a new B<IRC::Message::Object>; 
+shortcut for C<< IRC::Message::Object->new >>.
 
-Shortcut for C<< IRC::Message::Object->new >>
+This module uses L<Exporter::Tiny>, so you can rename the exported constructor
+if you like:
+
+  use IRC::Message::Object ircmsg => { -as => 'irc_ev' };
 
 =head2 Attributes and Methods
 
