@@ -1,10 +1,12 @@
 package IRC::Toolkit::Case;
 {
-  $IRC::Toolkit::Case::VERSION = '0.084002';
+  $IRC::Toolkit::Case::VERSION = '0.085000';
 }
 use strictures 1;
 
-use Exporter 'import';
+use Carp 'carp';
+
+use parent 'Exporter::Tiny';
 our @EXPORT = qw/
   lc_irc
   uc_irc
@@ -19,7 +21,12 @@ sub lc_irc ($;$) {
   $casemap = lc( $casemap || 'rfc1459' );
 
   CASE: {
-    if ($casemap eq 'strict-rfc1459') {
+    if ($casemap eq 'rfc1459') {
+      $string =~ tr/A-Z[]\\~/a-z{}|^/;
+      last CASE
+    }
+
+    if ($casemap eq 'strict-rfc1459' || $casemap eq 'strict') {
       $string =~ tr/A-Z[]\\/a-z{}|/;
       last CASE
     }
@@ -29,7 +36,9 @@ sub lc_irc ($;$) {
       last CASE
     }
 
-    $string =~ tr/A-Z[]\\~/a-z{}|^/
+    carp "Unknown CASEMAP $casemap, defaulted to rfc1459";
+    $casemap = 'rfc1459';
+    redo CASE
   }
 
   $string
@@ -40,6 +49,11 @@ sub uc_irc ($;$) {
   $casemap = lc( $casemap || 'rfc1459' );
 
   CASE: {
+    if ($casemap eq 'rfc1459') {
+      $string =~ tr/a-z{}|^/A-Z[]\\~/;
+      last CASE
+    }
+
     if ($casemap eq 'strict-rfc1459') {
       $string =~ tr/a-z{}|/A-Z[]\\/;
       last CASE
@@ -50,7 +64,9 @@ sub uc_irc ($;$) {
       last CASE
     }
 
-    $string =~ tr/a-z{}|^/A-Z[]\\~/
+    carp "Unknown CASEMAP $casemap, defaulted to rfc1459";
+    $casemap = 'rfc1459';
+    redo CASE
   }
 
   $string
@@ -95,6 +111,9 @@ C<strict-rfc1459>, or C<ascii>:
   'rfc1459'         a-z{}|^  -->  A-Z[]\~   (default)
   'strict-rfc1459'  a-z{}|   -->  A-Z[]\
 
+If told to convert/compare an unknown casemap, these functions will warn and
+default to RFC1459 rules.
+
 If you're building a class that tracks an IRC casemapping and manipulates
 strings accordingly, you may also want to see L<IRC::Toolkit::Role::CaseMap>.
 
