@@ -1,12 +1,12 @@
 package IRC::Toolkit::Colors;
 {
-  $IRC::Toolkit::Colors::VERSION = '0.084002';
+  $IRC::Toolkit::Colors::VERSION = '0.085000';
 }
 
 use Carp;
 use strictures 1;
 
-use Exporter 'import';
+use parent 'Exporter::Tiny';
 our @EXPORT = 'color';
 
 our %COLORS = (
