@@ -1,12 +1,15 @@
 package IRC::Toolkit::TS6;
 {
-  $IRC::Toolkit::TS6::VERSION = '0.084002';
+  $IRC::Toolkit::TS6::VERSION = '0.085000';
 }
 use strictures 1;
 use Carp;
 
-use Exporter 'import';
+use parent 'Exporter::Tiny';
 our @EXPORT = 'ts6_id';
+
+use namespace::clean;
+
 sub ts6_id {
   __PACKAGE__->new(@_)
 }
